# UpdateDataBatch

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**custom_fields** | **dict(str, object)** |  | [optional] 
**all** | **bool** |  | [optional] 
**close_notes** | **str** |  | [optional] 
**close_reason** | **str** |  | [optional] 
**columns** | **list[str]** |  | [optional] 
**data** | **dict(str, object)** |  | [optional] 
**filter** | [**IncidentFilter**](IncidentFilter.md) |  | [optional] 
**force** | **bool** |  | [optional] 
**ids** | **list[str]** |  | [optional] 
**line** | **str** |  | [optional] 
**original_incident_id** | **str** |  | [optional] 
**override_investigation** | **bool** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


